@@ -38,7 +38,7 @@
   #:use-module (ice-9 format)
   #:use-module (ice-9 match)
   #:use-module (ice-9 receive)
-  #:use-module ((srfi srfi-1) #:select (filter-map find))
+  #:use-module ((srfi srfi-1) #:select (filter-map find remove))
   #:use-module (oop goops)
   #:use-module (g-golf support)
   #:use-module (g-golf glib)
@@ -49,7 +49,8 @@
   #:use-module (g-golf hl-api iface)
 
   #:replace (connect
-             map)
+             map
+             remove)
 
   #:duplicates (merge-generics
 		replace
@@ -101,6 +102,13 @@
   "The core Guile implementation of the map call"
   (apply %map args))
 
+(define %remove
+  (module-ref (resolve-module '(srfi srfi-1)) 'remove))
+
+(define-method (remove . args)
+  "The core Guile implementation of the remove call"
+  (apply %remove args))
+
 ;; Same as above, in order to avoid the following warning [1], the
 ;; disconnect gf must be added and exported from this module. This is
 ;; because this module, which does not use (g-golf hl-api signal), is
@@ -588,7 +596,10 @@ vfunc, so those newly added properties won't work as expected.
                (null-pointer? value))
            #f
            (or (g-inst-cache-ref value)
-               (let ((class (g-type-cache-ref g-type)))
+               ;; the instance class could be a subclass of the one
+               ;; given by g-type (which is the one given by the property
+               ;; g-param specs
+               (let ((class (g-object-find-class value)))
                  (make class #:g-inst value))))))
     (else
      (g-value-ref g-value))))
